@@ -8,7 +8,7 @@ use Perl::Critic::Utils::Constants qw(@STRICT_EQUIVALENT_MODULES @WARNINGS_EQUIV
 use parent 'Perl::Critic::Policy';
 use version;
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use constant DESC => 'Missing strict or warnings';
 use constant EXPL => 'The strict and warnings pragmas are important to avoid common pitfalls and deprecated/experimental functionality. Make sure each script or module contains "use strict; use warnings;" or a module that does this for you.';
@@ -28,7 +28,6 @@ sub default_themes { 'freenode' }
 sub applies_to { 'PPI::Document' }
 
 my @incomplete_importers = qw(common::sense sanity);
-my @add_importers = qw(Mouse::Util Any::Moose strictures);
 
 sub violates {
 	my ($self, $elem) = @_;
@@ -42,9 +41,6 @@ sub violates {
 	delete $strict_importers{$_} for @incomplete_importers;
 	delete $warnings_importers{$_} for @incomplete_importers;
 	
-	# Add additional importers
-	$strict_importers{$_} = $warnings_importers{$_} = 1 for @add_importers;
-	
 	# Add extra importers
 	$strict_importers{$_} = $warnings_importers{$_} = 1 foreach keys %{$self->{_extra_importers}};
 	
